/*-
 * Copyright 2007 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <sys/errno.h>
#include "dtt7612.h"
#include "or51132.h"
#include "tda9887.h"
#include "cx88_debug.h"
#include "pchdtv_hd3000.h"

namespace cx88_mpeg_driver_factory
{

   int pchdtv_hd3000::create_i2c_drivers(void)
   {
      m_i2c_devs[0].driver = new dtt7612(m_tunerconf, *(m_i2c_devs[0].dev));
      m_i2c_devs[1].driver = new or51132(m_tunerconf, *(m_i2c_devs[1].dev));
      if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
      {
         CX88ERR << "Error initializing tuner/demodulator driver for pcHDTV HD-3000" << std::endl;
         return ENOMEM;
      }
      return 0;
   }
   
   void pchdtv_hd3000::destroy_i2c_drivers(void)
   {
      delete m_i2c_devs[1].driver;
      delete m_i2c_devs[0].driver;  
   }
   
   int pchdtv_hd3000::create_i2c_devices(void)
   {
      m_i2c_devs[0].conf.in_addr = 0x61;
      m_i2c_devs[1].conf.in_addr = 0x15;
      return 0;
   }
}

namespace cx88_analog_driver_factory
{

   const cx88_source pchdtv_hd3000::m_sources[] =
      {{"Tuner",     "RF input",                  cx88_driver::CX88_SOURCE_DEFAULT},
       {"SVideo",    "S-video input",             pchdtv_hd3000::HD3000_SOURCE_SVIDEO},
       {"Composite", "Composite video input",     pchdtv_hd3000::HD3000_SOURCE_COMPOSITE},
       {NULL,        NULL,                        0}};
      

   int pchdtv_hd3000::create_i2c_drivers(void)
   {
      m_i2c_devs[0].driver = new dtt7612(m_tunerconf, *(m_i2c_devs[0].dev));
      m_i2c_devs[1].driver = new tda9887(m_tunerconf, *(m_i2c_devs[1].dev), TDA9887_OPTION_RADIO_IF_41_3 | TDA9887_OPTION_RADIO_GAIN_NORM);
      if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
      {
         CX88ERR << "Error initializing analog tuner/demodulator drivers for pcHDTV HD-3000" << std::endl;
         return ENOMEM;
      }
      return 0;
   }
   
   void pchdtv_hd3000::destroy_i2c_drivers(void)
   {
      delete m_i2c_devs[0].driver;
      delete m_i2c_devs[1].driver;
   }
   
   int pchdtv_hd3000::create_i2c_devices(void)
   {
      m_i2c_devs[0].conf.in_addr = 0x61;
      m_i2c_devs[0].source_mask = CX88_SOURCE_DEFAULT;
      m_i2c_devs[1].conf.in_addr = 0x43;
      m_i2c_devs[1].source_mask = CX88_SOURCE_DEFAULT;
      return 0;
   }

   int pchdtv_hd3000::select_source(uint32_t source_mask)
   {
      switch (source_mask)
      {
         case CX88_SOURCE_DEFAULT:
            m_input_mux = CX88_VIDEO_INPUT_MUX1;
            m_input_type = CX88_VIDEO_INPUT_COMPOSITE;
            break;
         case HD3000_SOURCE_SVIDEO:
            m_input_mux = CX88_VIDEO_INPUT_MUX3;
            m_input_type = CX88_VIDEO_INPUT_SVIDEO;
            break;
         case HD3000_SOURCE_COMPOSITE:
            m_input_mux = CX88_VIDEO_INPUT_MUX2;
            m_input_type = CX88_VIDEO_INPUT_COMPOSITE;
            break;
         default:
            return EINVAL;
      }
      return 0;
   }

   int pchdtv_hd3000::set_capture_options(cx88_video_capture &capture)
   {
      capture.in_input_source = m_input_mux;
      capture.in_input_type = m_input_type;
      return 0;
   }
}

