/*-
 * Copyright 2009 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __WINTV_HVR1800_H__
#define __WINTV_HVR1800_H__

#include "tda18271.h"
#include "cx88_mpeg_driver.h"
#include "cx88_analog_driver.h"

namespace cx88_mpeg_driver_factory
{

   class wintv_hvr1800
      : public cx88_mpeg_driver
   {
      public:
         
         enum hvr1800_tuner_t
         {
            HVR1800_TUNER_MICROTUNE,
            HVR1800_TUNER_MICROTUNE_NXP
         };
         
         wintv_hvr1800(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            hvr1800_tuner_t tuners,
            int &error)
            : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error),
              m_tuners(tuners)
         {}
         
         virtual ~wintv_hvr1800(void) {}

         virtual const char *get_name(void)
         {
            return "WinTV HVR-1800";
         }

         virtual uint32_t get_caps(void)
         {
            return CX88_MPEG_CAP_ATSC | CX88_MPEG_CAP_QAM;
         }

         virtual const cx88_source *get_sources(void);

      protected:
         
         static const uint32_t HVR1800_SOURCE_SECONDARY = 1 << 1;

         static const cx88_source m_sources[3];

         static int tda18271_interface_config(tda18271 &driver, const dvb_channel &channel, tda18271_interface &ifc);

         virtual int create_i2c_drivers(void);

         virtual void destroy_i2c_drivers(void);

         virtual int create_i2c_devices(void);

         virtual int select_source(uint32_t source_mask);

         virtual int set_channel_options(dvb_channel &channel); 

         hvr1800_tuner_t m_tuners;
   };
};

namespace cx88_analog_driver_factory
{
   class wintv_hvr1800
      : public cx88_analog_driver
   {
      public:
         
         wintv_hvr1800(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            cx88_analog_mode mode,
            cx88_analog_driver *slave,
            cx88_analog_driver *pip_driver,
            int &error)
            : cx88_analog_driver(cx88conf, tunerconf, devnode, captures, mode, slave, pip_driver, error)
         {}
         
         virtual ~wintv_hvr1800(void) {}

         virtual const char *get_name(void)
         {
            return "WinTV HVR-1800";
         }

         virtual uint32_t get_caps(void)
         {
            return CX88_ANALOG_CAP_LINE_IN | CX88_ANALOG_CAP_FM | CX88_ANALOG_CAP_VOLUME | CX88_ANALOG_CAP_MUTE;
         }

         const cx88_source *get_sources(void)
         {
            return m_sources;
         }

      protected:

         static const uint32_t HVR1800_SOURCE_LINEIN = 1 << 1;

         static const cx88_source m_sources[3];
      
         uint8_t m_audio_input;

         virtual int create_i2c_devices(void);

         virtual int create_i2c_drivers(void);

         virtual void destroy_i2c_drivers(void);

         virtual int select_source(uint32_t source_mask);

         virtual int set_format_options(cx88_audio_format &format);

   };
};

#endif

