/*-
 * Copyright 2011 Jason Harmening
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __WINTV_PCI_FM_H__
#define __WINTV_PCI_FM_H__

#include "cx88_analog_driver.h"

namespace cx88_analog_driver_factory
{
   class wintv_pci_fm
      : public cx88_analog_driver
   {
      public:
         
         wintv_pci_fm(
            cx88_xml_config &cx88conf,
            tuner_config &tunerconf,
            const char *devnode,
            capvec &captures,
            cx88_analog_mode mode,
            cx88_analog_driver *slave,
            cx88_analog_driver *pip_driver,
            int &error)
            : cx88_analog_driver(cx88conf, tunerconf, devnode, captures,
               ((mode == CX88_ANALOG_MODE_AUDIO) ? CX88_ANALOG_MODE_AUDIO_OSS : mode),
               slave, pip_driver, error)
         {
            if (mode != CX88_ANALOG_MODE_VIDEO)
            {
               std::cout << "Warning: This card does not support DMA audio." << std::endl <<
                  "Please run an audio cable from the card's line-out jack to your soundcard's line-in jack." << std::endl;
            }
         }
         
         virtual ~wintv_pci_fm(void) {}

         virtual const char *get_name(void)
         {
            return "WinTV PCI-FM";
         }

         virtual uint32_t get_caps(void)
         {
            return CX88_ANALOG_CAP_TV | CX88_ANALOG_CAP_SVIDEO | CX88_ANALOG_CAP_COMPOSITE |
                   CX88_ANALOG_CAP_NTSC | CX88_ANALOG_CAP_PAL | CX88_ANALOG_CAP_SECAM | CX88_ANALOG_CAP_TV_AUDIO |
                   CX88_ANALOG_CAP_FM | CX88_ANALOG_CAP_MUTE | CX88_ANALOG_CAP_LINE_IN;
         }

         virtual const cx88_source *get_sources(void)
         {
            return m_sources;
         }

      protected:

         static const uint32_t PCIFM_SOURCE_SVIDEO = 1 << 1;
         static const uint32_t PCIFM_SOURCE_COMPOSITE = 1 << 2;
         static const uint32_t PCIFM_SOURCE_LINEIN = 1 << 3;
         static const cx88_source m_sources[6];

         uint8_t m_gpio;
         uint8_t m_input_mux;
         uint8_t m_input_type;

         virtual int create_i2c_drivers(void);

         virtual void destroy_i2c_drivers(void);

         virtual int create_i2c_devices(void);

         virtual int select_source(uint32_t source_mask);

         virtual int set_capture_options(cx88_video_capture &capture);

         virtual int set_channel_options(avb_channel &channel);
   };
   
}

#endif

